@@ -7,7 +7,7 @@
 
 /***********************************************************************
  *
- * Copyright 2002, 2003, 2004, 2005, 2006, 2007 Free Software Foundation, Inc.
+ * Copyright 2002, 2003, 2004, 2005, 2006, 2007, 2008 Free Software Foundation, Inc.
  * Written by Paolo Bonzini.  Ideas based on Mike Haertel's malloc.
  *
  * This file is part of GNU Smalltalk.
@@ -261,8 +261,11 @@ nospace:
       if (h->heap_limit && h->heap_total <= h->heap_limit
 	  && h->heap_total + nsz > h->heap_limit && h->nomemory)
 	{
-	  h->nomemory (h, nsz);
-	  break;
+	  h = h->nomemory (h, nsz);
+	  if (h)
+	    break;
+	  else
+	    return NULL;
 	}
 
     case 2:
