@@ -130,9 +130,9 @@ typedef struct gst_identity_dictionary
 #define BEHAVIOR_HEADER \
   OBJ_HEADER; \
   OOP		superclass; \
+  OOP		subClasses; \
   OOP		methodDictionary; \
   intptr_t	instanceSpec; \
-  OOP		subClasses; \
   OOP		instanceVariables
 
 typedef struct gst_behavior
@@ -158,34 +158,6 @@ typedef struct gst_behavior
 #define COBJECT_INT_TYPE		FROM_INT(10)
 #define COBJECT_UNSIGNED_INT_TYPE	FROM_INT(11)
 
-/*    3                   2                   1
-    1 0 9 8 7 6 5 4 3 2 1 0 9 8 7 6 5 4 3 2 1 0 9 8 7 6 5 4 3 2 1 0
-   +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
-   |    # fixed fields             |      unused       |I| kind  |1|
-   +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
-
-   I'm moving it to bits 13-30 (it used to stay at bits 5-30),
-   allocating space for more flags in case they're needed.
-   If you change ISP_NUMFIXEDFIELDS you should modify Behavior.st too.
-   Remember to shift by ISP_NUMFIXEDFIELDS-1 there, since Smalltalk does
-   not see GST_ISP_INTMARK!!  */
-
-enum {
-  ISP_NUMFIXEDFIELDS = 13,
-
-  /* Set if the instances of the class have indexed instance
-     variables.  */
-  ISP_ISINDEXABLE = 32,
-
-  /* These represent the shape of the indexed instance variables of
-     the instances of the class.  */
-  ISP_INDEXEDVARS = 62,
-  ISP_SHAPE = 30,
-
-  /* Set to 1 to mark a SmallInteger.  */
-  GST_ISP_INTMARK = 1
-};
-
 typedef struct gst_class_description
 {
   CLASS_DESCRIPTION_HEADER;
@@ -319,7 +291,6 @@ typedef struct gst_cobject
 {
   OBJ_HEADER;
   OOP type;
-  OOP storage;
 }
  *gst_cobject;
 
@@ -456,7 +427,6 @@ extern OOP _gst_binding_dictionary_new (int size,
    it.  If the methodDictionary associated with CLASS_OOP is nil, one
    is created and installed into that class.  */
 extern OOP _gst_valid_class_method_dictionary (OOP class_oop)
-  ATTRIBUTE_PURE 
   ATTRIBUTE_HIDDEN;
 
 /* This returns the dictionary of class variables for CLASS_OOP */
@@ -545,14 +515,12 @@ extern OOP _gst_shared_pool_dictionary (OOP class_oop)
   ATTRIBUTE_PURE 
   ATTRIBUTE_HIDDEN;
 
-/* Creates a new CObject pointing to cObjOfs bytes in BASEOOP (or
-   at the absolute address cObjOfs if BASEOOP is NULL), extracting the class
+/* Creates a new CObject pointing to cObjPtr, extracting the class
    to be instantiated from the CType, TYPEOOP, or using the provided
    class if TYPEOOP is nil.  */
-extern OOP _gst_c_object_new_base (OOP baseOOP,
-			           uintptr_t cObjOfs,
-			           OOP typeOOP,
-			           OOP defaultClassOOP) 
+extern OOP _gst_c_object_new (PTR cObjPtr,
+			      OOP typeOOP,
+			      OOP defaultClassOOP) 
   ATTRIBUTE_HIDDEN;
 
 /* Creates a new String with LEN indexed instance variables.  */
