@@ -129,7 +129,7 @@ static void gen_prim_id (const char *name, int id, const char *attrs);
 static int lookup_prim_id (const char *s);
 static void free_data ();
 static void output ();
-static char *strupr (char *s);
+static char *strtoupper (char *s);
 
 #define YYPRINT(fp, tok, val) fprintf (fp, "%s", val);
 
@@ -176,8 +176,8 @@ typedef union YYSTYPE
   char *text;
   int id;
 }
-/* Line 193 of yacc.c.  */
-#line 181 "../../libgst/genpr-parse.c"
+/* Line 187 of yacc.c.  */
+#line 181 "genpr-parse.c"
 	YYSTYPE;
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
@@ -190,7 +190,7 @@ typedef union YYSTYPE
 
 
 /* Line 216 of yacc.c.  */
-#line 194 "../../libgst/genpr-parse.c"
+#line 194 "genpr-parse.c"
 
 #ifdef short
 # undef short
@@ -1470,7 +1470,7 @@ yyreduce:
 #line 190 "genpr-parse.y"
     {
 	    (yyval.text) = fildelete ((yyvsp[(2) - (3)].fil));
-	    strupr ((yyval.text));
+	    strtoupper ((yyval.text));
 	  }
     break;
 
@@ -1545,7 +1545,7 @@ yyreduce:
 
 
 /* Line 1267 of yacc.c.  */
-#line 1549 "../../libgst/genpr-parse.c"
+#line 1549 "genpr-parse.c"
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);
@@ -1803,7 +1803,7 @@ gen_prim_decl (const char *s)
 }
 
 char *
-strupr (char *s)
+strtoupper (char *s)
 {
   char *base = s;
   while (*s)
@@ -1866,7 +1866,7 @@ void
 output()
 {
   char *proto, *stmt, *def;
-  unsigned int md5[16 / sizeof (int)];
+  unsigned char md5[16];
 
   gen_proto ("VMpr_HOLE");
 
@@ -1889,7 +1889,9 @@ output()
 	  "  PRIM_FAILED;\n"
 	  "}\n"
 	  "\n"
-	  "int _gst_primitives_md5[4] = { 0x%x, 0x%x, 0x%x, 0x%x };\n"
+	  "unsigned char\n"
+	  "_gst_primitives_md5[16] = { %d, %d, %d, %d, %d, %d, %d, %d,\n"
+	  "                            %d, %d, %d, %d, %d, %d, %d, %d };\n"
 	  "\n"
 	  "void\n"
 	  "_gst_init_primitives()\n"
@@ -1907,7 +1909,8 @@ output()
 	  "}\n"
 	  "\n",
 	  proto, stmt,
-	  md5[0], md5[1], md5[2], md5[3],
+	  md5[0], md5[1], md5[2], md5[3], md5[4], md5[5], md5[6], md5[7],
+	  md5[8], md5[9], md5[10], md5[11], md5[12], md5[13], md5[14], md5[15],
 	  def, prim_no + 1);
 
   free (proto);
