@@ -301,7 +301,7 @@ static inline mst_Boolean cached_index_oop_put_primitive (OOP rec,
 
 /* Locates in the ProcessorScheduler's process lists and returns the
    highest priority process different from the current process.  */
-static OOP highest_priority_process (void) ATTRIBUTE_PURE;
+static OOP highest_priority_process (void);
 
 /* Remove the head of the given list (a Semaphore is a subclass of
    LinkedList) and answer it.  */
@@ -424,10 +424,9 @@ static inline OOP create_args_array (int numArgs);
    the arguments in the block context, which have been copied out of
    the caller's context. 
 
-   The block should accept between NUMARGS - CULL_UP_TO and
-   NUMARGS arguments.  If this is not true (failure) return true;
-   on success return false.  */
-static mst_Boolean send_block_value (int numArgs, int cull_up_to);
+   On failure return true, on success (i.e. if NUMARGS matches what
+   the BlockClosure says) return false.  */
+static mst_Boolean send_block_value (int numArgs);
 
 /* This is a kind of simplified _gst_send_message_internal that,
    instead of setting up a context for a particular receiver, stores
@@ -485,7 +484,7 @@ static void unwind_context (void);
    _gst_nil_oop or directly call _gst_selector_num_args.  */
 static inline mst_Boolean check_send_correctness (OOP receiver,
 						  OOP sendSelector,
-						  int numArgs) ATTRIBUTE_PURE;
+						  int numArgs);
 
 /* Unwind the contexts up until the caller of the method that
    created the block context, no matter how many levels of message
@@ -2564,7 +2563,7 @@ _gst_show_backtrace (void)
 	      if (IS_NIL(context->parentContext))
 	        printf ("<bottom>\n");
 	      else
-	        printf ("<unwind point>\n");
+	        printf ("<call-in>\n");
 	      continue;
 	    }
 
