@@ -7,7 +7,7 @@
 
 /***********************************************************************
  *
- * Copyright 2000, 2001, 2002, 2003, 2006 Free Software Foundation, Inc.
+ * Copyright 2000, 2001, 2002, 2003, 2006, 2008 Free Software Foundation, Inc.
  * Written by Paolo Bonzini.
  *
  * This file is part of GNU Smalltalk.
@@ -201,7 +201,7 @@ static int compare_blocks (const PTR a, const PTR b) ATTRIBUTE_PURE;
 static int search_block (const PTR a, const PTR b) ATTRIBUTE_PURE;
 
 /* Computes the length of a jump at distance OFS.  */
-static int compute_jump_length (int ofs) ATTRIBUTE_PURE;
+static int compute_jump_length (int ofs) ATTRIBUTE_CONST;
 
 /* This answers how the dirtyness of BLOCKOOP affects
    the block that encloses it.  */
